===============================
Python libusdt bindings
===============================

.. image:: https://badge.fury.io/py/usdt.png
    :target: http://badge.fury.io/py/usdt
    
.. image:: https://pypip.in/d/usdt/badge.png
        :target: https://pypi.python.org/pypi/usdt


Python libusdt bindings

* Free software: BSD license
* Documentation: http://usdt.readthedocs.org.

Features
--------

* Create USDT providers and probes
* Fire probes
* Fallback mode
